﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="Content" xmlns="http://purl.oclc.org/dsdl/schematron" xmlns:function="http://ato.gov.au/SWSFunctions">
  <title>Income Tests Content Validations</title>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">

    <let name="startDate" value="xbrli:context[@id = $IITR.RP.ContextId]/xbrli:period/xbrli:startDate"/>
    <let name="endDate" value="xbrli:context[@id = $IITR.RP.ContextId]/xbrli:period/xbrli:endDate"/>
    
    <!-- Rule ID: VR.ATO.IITR.000089
         ELS Ref: V2361

		    IF ([iitr236] > 0) 
           AND 
           (
              [iitr217] > CONVERT_TO_DATE(30,6, [iitr10] - 55 )
           ) 
           OR 
           (
              [iitr217] <= CONVERT_TO_DATE(1,7,[iitr10] - 61)
           )
		     RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr10] = pyin.xx.xx:Report.TargetFinancial.Year
		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
		    [iitr236] = emsup.xx.xx:SuperannuationPayment.BenefitLumpSumZeroTaxRate.Amount
    -->    
    <let name="years55Ago" value="concat($iitr10 - 55, '-06-30')" />
    <let name="years61Ago" value="concat($iitr10 - 61, '-07-01')" />
    
    <assert id="VR.ATO.IITR.000089" diagnostics="DVR.ATO.IITR.000089"
            test="not(
                          sum($iitr236) > 0
                          and
                          (
                              $iitr217
                              [
                                  function:IsDate1GreaterThanDate2(., $years55Ago)
                                  or
                                  function:IsDate1GreaterOrEqualToDate2($years61Ago, .)
                              ]
                          )                          
                      )" />
    

    <!-- Rule ID: VR.ATO.IITR.100063
         ELS Ref: V2064

		    IF ([iitr533] <> NULLORBLANK) AND ([iitr213] = NULLORBLANK OR [iitr214] = NULLORBLANK OR [iitr217] = NULL OR [iitr218] <> NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
		    [iitr218] = pyde.xx.xx:PersonDemographicDetails.Sex.Code
		    [iitr533] = pyid.xx.xx:Identifiers.FamilyAssistanceOfficeCustomerReferenceNumber.Identifier
    -->
    <assert id="VR.ATO.IITR.100063" diagnostics="DVR.ATO.IITR.100063"
            test="not(
                          $iitr533[not(@i:nil='true') and string-length(.) != 0]
                          and
                          (
                              not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                              or
                              not($iitr214[not(@i:nil='true') and string-length(.) != 0])
                              or
                              not($iitr217[not(@i:nil='true')])
                              or
                              not($iitr218[not(@i:nil='true') and string-length(.) != 0])
                          )                          
                      )" />


 
    <!-- Rule ID: VR.ATO.IITR.200018
         ELS Ref: V2362

         IF 
          ([iitr163] = SET("Eligible spouse lived apart", "Non eligible spouse lived apart", "Eligible spouse lived together", "Non eligible spouse lived together")) 
          AND ([iitr225] = NULL)
            RETURN VALIDATION MESSAGE
         ENDIF
         
		     [iitr163] = gfati.xx.xx:TaxOffsetClaim.SeniorAndPensioner.Code
		     [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount (Spouse)
    -->
    <assert id="VR.ATO.IITR.200018" diagnostics="DVR.ATO.IITR.200018"
            test="not(
                          $iitr163
                           [
                            . = 'Eligible spouse lived apart' 
                            or 
                            . = 'Non eligible spouse lived apart' 
                            or 
                            . = 'Eligible spouse lived together' 
                            or 
                            . = 'Non eligible spouse lived together'
                           ]
                          and
                          not($iitr225[not(@i:nil='true')])
                      )" />
    

    <!-- Rule ID: VR.ATO.IITR.200021
         ELS Ref: V2362

         IF ([iitr163] <> NULLORBLANK AND [iitr163] <> "Single") AND [iitr218] = NULLORBLANK
            RETURN VALIDATION MESSAGE
         ENDIF
         
		     [iitr163] = gfati.xx.xx:TaxOffsetClaim.SeniorAndPensioner.Code
		     [iitr218] = pyde.xx.xx:PersonDemographicDetails.Sex.Code (Spouse)
    -->
    <assert id="VR.ATO.IITR.200021" diagnostics="DVR.ATO.IITR.200021"
            test="not(
                          $iitr163[not(@i:nil='true') and string-length(.) != 0]
                          and
                          $iitr163[. != 'Single']
                          and
                          not($iitr218[not(@i:nil='true') and string-length(.) != 0])
                      )" />
    

    <!-- Rule ID: VR.ATO.IITR.200024
         ELS Ref: V2362

         IF (
              [iitr164] = "Both" 
              OR 
              [iitr164] = "Spouse Veteran War Widow Widower"
            ) 
            AND 
            (
              [iitr225] = NULL 
              OR 
              [iitr229] = NULL 
              OR
              [iitr230] = NULL
            )
            RETURN VALIDATION MESSAGE
         ENDIF
         
		     [iitr164] = gfati.xx.xx:TaxOffsetClaim.Veteran.Code
		     [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount (Spouse)
         [iitr229] = gfapc.xx.xx:Pension.Total.Amount (Spouse)
         [iitr230] = gfapc.xx.xx:Pension.SpouseExempt.Amount (Spouse)
    -->
    <assert id="VR.ATO.IITR.200024" diagnostics="DVR.ATO.IITR.200024"
            test="not(
                          $iitr164
                           [
                            . = 'Spouse Veteran War Widow Widower' 
                            or 
                            . = 'Both'
                           ]
                          and
                          (
                            not($iitr225[not(@i:nil='true')])
                            or
                            not($iitr229[not(@i:nil='true')])
                            or
                            not($iitr230[not(@i:nil='true')])
                          )
                      )" />


    <!-- Rule ID: VR.ATO.IITR.200030
         ELS Ref: V131

		    IF ([iitr213] <> NULLORBLANK AND [iitr171] > 0) AND ([iitr225] = NULL)
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr171] = rvctc2.xx.xx:IncomeTax.MedicareLevy.DependentChildrenAndStudents.Count
		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount
    -->
    <assert id="VR.ATO.IITR.200030" diagnostics="DVR.ATO.IITR.200030"
            test="not(
                          $iitr213[not(@i:nil='true') and string-length(.) != 0]
                          and
                          sum($iitr171) > 0                          
                          and
                          not($iitr225[not(@i:nil='true')])
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.210014
         ELS Ref: V2360

		    IF [iitr386] > 0 
          AND 
          (
            [iitr220]=TRUE 
            OR 
            (
              [iitr221] <> NULL 
              AND 
              [iitr222] <> NULL
            )
          ) 
          AND 
          [iitr225] = NULL
           RETURN VALIDATION MESSAGE
        ENDIF

		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
		    [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
        [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount (Spouse)
        [iitr386] = gfati.xx.xx:TaxOffsetClaim.DependentInvalidAndCarer.Amount
    -->
    <assert id="VR.ATO.IITR.210014" diagnostics="DVR.ATO.IITR.210014"
            test="not(
                          sum($iitr386) > 0
                          and
                          (
                              $iitr220[matches(.,'^(true|1)$')]
                              or
                              (
                                $iitr221[not(@i:nil='true')]
                                and
                                $iitr222[not(@i:nil='true')]
                              )
                          )
                          and 
                          not($iitr225[not(@i:nil='true')])
                      )" />


    <!-- Rule ID: VR.ATO.IITR.210018
         ELS Ref: V282

		    IF ([iitr379] > 0 AND ([iitr213] = NULLORBLANK OR [iitr225] = NULL))
		      RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount
		    [iitr379] = gfati.xx.xx:TaxOffsetClaim.SuperannuationContributionSpouse.Amount
    -->
    <assert id="VR.ATO.IITR.210018" diagnostics="DVR.ATO.IITR.210018"
            test="not(
                          sum($iitr379) > 0
                          and
                          (
                              not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                              or
                              not($iitr225[not(@i:nil='true')])
                          )                  
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.300030
         ELS Ref: V104A
         
         IF (
              [iitr436] <> NULL 
              OR 
              [iitr437] <> NULL 
              OR 
              [iitr438] <> NULL 
              OR
              [iitr439] <> NULL
              OR
              [iitr440] <> NULL
              OR 
              [iitr441] <> NULL 
              OR 
              [iitr442] <> NULL 
              OR
              [iitr443] <> NULL
              OR 
              [iitr445] <> NULL 
              OR 
              [iitr447] <> NULL 
              OR
              [iitr448] <> NULL 
              OR 
              [iitr279] <> NULL
            ) 
            AND 
            [iitr419] = NULLORBLANK
              RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr419] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr436] = bafpr1.xx.xx:Income.ABNNotQuotedPrimaryProductionPaymentGross.Amount
         [iitr437] = bafpr1.xx.xx:Income.ABNNotQuotedNonPrimaryProductionPaymentGross.Amount
         [iitr438] = bafpr1.xx.xx:Income.ForeignResidentWithholdingNonPrimaryProduction.Amount
         [iitr439] = bafpr1.xx.xx:Income.VoluntaryAgreementPrimaryProductionGross.Amount
         [iitr440] = bafpr1.xx.xx:Income.VoluntaryAgreementNonPrimaryProductionGross.Amount
         [iitr441] = bafpr1.xx.xx:Income.LabourHireArrangementPrimaryProductionPaymentGross.Amount
         [iitr442] = bafpr1.xx.xx:Income.LabourHireArrangementNonPrimaryProductionPaymentGross.Amount
         [iitr443] = bafpr1.xx.xx:Income.GovernmentIndustryPrimaryProductionPaymentsAssessable.Amount
         [iitr445] = bafpr1.xx.xx:Income.GovernmentIndustryNonPrimaryProductionPaymentsAssessable.Amount
         [iitr447] = bafpr1.xx.xx:Income.BusinessPrimaryProductionOther.Amount
         [iitr448] = bafpr1.xx.xx:Income.BusinessNonPrimaryProductionOther.Amount
         [iitr279] = bafpr3.xx.xx:Income.PersonalServicesIncome.Net.Amount
      -->
    <assert id="VR.ATO.IITR.300030" diagnostics="DVR.ATO.IITR.300030"
            test="not(
                          not($iitr419[not(@i:nil='true') and string-length(.) != 0])
                          and
                          (
                            $iitr436[not(@i:nil='true')]
                            or
                            $iitr437[not(@i:nil='true')]
                            or
                            $iitr438[not(@i:nil='true')]
                            or
                            $iitr439[not(@i:nil='true')]
                            or
                            $iitr440[not(@i:nil='true')]
                            or
                            $iitr441[not(@i:nil='true')]
                            or
                            $iitr442[not(@i:nil='true')]
                            or
                            $iitr443[not(@i:nil='true')]
                            or
                            $iitr445[not(@i:nil='true')]
                            or
                            $iitr447[not(@i:nil='true')]
                            or
                            $iitr448[not(@i:nil='true')]
                            or
                            $iitr279[not(@i:nil='true')]
                          )
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.300031
         ELS Ref: V104B
         
         IF [iitr419] <> NULLORBLANK AND 
          (
            ([iitr418] = NULLORBLANK) OR 
            (
              [iitr436] = NULL AND 
              [iitr437] = NULL AND 
              [iitr438] = NULL AND 
              [iitr439] = NULL AND 
              [iitr440] = NULL AND 
              [iitr441] = NULL AND 
              [iitr442] = NULL AND 
              [iitr443] = NULL AND 
              [iitr445] = NULL AND 
              [iitr447] = NULL AND 
              [iitr448] = NULL AND 
              [iitr279] = NULL
            )
          )
           RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr419] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr418] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
         [iitr436] = bafpr1.xx.xx:Income.ABNNotQuotedPrimaryProductionPaymentGross.Amount
         [iitr437] = bafpr1.xx.xx:Income.ABNNotQuotedNonPrimaryProductionPaymentGross.Amount
         [iitr438] = bafpr1.xx.xx:Income.ForeignResidentWithholdingNonPrimaryProduction.Amount
         [iitr439] = bafpr1.xx.xx:Income.VoluntaryAgreementPrimaryProductionGross.Amount
         [iitr440] = bafpr1.xx.xx:Income.VoluntaryAgreementNonPrimaryProductionGross.Amount
         [iitr441] = bafpr1.xx.xx:Income.LabourHireArrangementPrimaryProductionPaymentGross.Amount
         [iitr442] = bafpr1.xx.xx:Income.LabourHireArrangementNonPrimaryProductionPaymentGross.Amount
         [iitr443] = bafpr1.xx.xx:Income.GovernmentIndustryPrimaryProductionPaymentsAssessable.Amount
         [iitr445] = bafpr1.xx.xx:Income.GovernmentIndustryNonPrimaryProductionPaymentsAssessable.Amount
         [iitr447] = bafpr1.xx.xx:Income.BusinessPrimaryProductionOther.Amount
         [iitr448] = bafpr1.xx.xx:Income.BusinessNonPrimaryProductionOther.Amount
         [iitr279] = bafpr3.xx.xx:Income.PersonalServicesIncome.Net.Amount
      -->
    <assert id="VR.ATO.IITR.300031" diagnostics="DVR.ATO.IITR.300031"
            test="not(
                          $iitr419[not(@i:nil='true') and string-length(.) != 0]
                          and
                          (
                            not($iitr418[not(@i:nil='true') and string-length(.) != 0])
                            or
                            (
                              not($iitr436[not(@i:nil='true')])
                              and
                              not($iitr437[not(@i:nil='true')])
                              and
                              not($iitr438[not(@i:nil='true')])
                              and
                              not($iitr439[not(@i:nil='true')])
                              and
                              not($iitr440[not(@i:nil='true')])
                              and
                              not($iitr441[not(@i:nil='true')])
                              and
                              not($iitr442[not(@i:nil='true')])
                              and
                              not($iitr443[not(@i:nil='true')])
                              and
                              not($iitr445[not(@i:nil='true')])
                              and
                              not($iitr447[not(@i:nil='true')])
                              and
                              not($iitr448[not(@i:nil='true')])
                              and
                              not($iitr279[not(@i:nil='true')])
                            )
                          )
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.300032
         ELS Ref: V105
         
         IF 
          (
            [iitr510] > 0
            OR 
            [iitr512] > 0
            OR 
            [iitr514] > 0 
            OR
            [iitr518] > 0 
            OR 
            [iitr520] > 0 
            OR 
            [iitr522] > 0 
            OR 
            [iitr524] > 0 
            OR
            [iitr526] > 0
          ) 
          AND 
          (
            [iitr281] = NULL 
            AND 
            [iitr285] = NULL
          )
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr281] = bafpr1.xx.xx:Income.PrimaryProductionNet.Amount
         [iitr285] = bafpr1.xx.xx:Income.NonPrimaryProductionNet.Amount
         [iitr510] = bafpo1.xx.xx:Assets.TradeandReceivablesOther.Amount
         [iitr512] = bafpo1.xx.xx:Liabilities.TradeAndOtherPayablesTotal.Amount
         [iitr514] = lrla.xx.xx:Remuneration.WagesAndSalaries.Total.Amount
         [iitr518] = lrla.xx.xx:Remuneration.PaymentToRelatedPartiesGross.Amount
         [iitr520] = bafpr3.xx.xx:Expense.DepreciatingAssets.IntangibleFirstDeducted.Amount
         [iitr522] = bafpr3.xx.xx:Expense.DepreciatingAssets.OtherFirstDeducted.Amount
         [iitr524] = bafpo7.xx.xx:Assets.DepreciatingAssets.IntangibleTerminationValue.Amount
         [iitr526] = bafpo7.xx.xx:Assets.DepreciatingAssets.OtherTerminationValue.Amount
      -->
    <assert id="VR.ATO.IITR.300032" diagnostics="DVR.ATO.IITR.300032"
            test="not(
                       (
                          sum($iitr510) > 0
                          or
                          sum($iitr512) > 0
                          or
                          sum($iitr514) > 0
                          or
                          sum($iitr518) > 0
                          or
                          sum($iitr520) > 0
                          or
                          sum($iitr522) > 0
                          or
                          sum($iitr524) > 0
                          or
                          sum($iitr526) > 0
                       )
                       and
                       (
                          not($iitr281[not(@i:nil='true')])
                          and
                          not($iitr285[not(@i:nil='true')])
                       )
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.300039
         ELS Ref: V1380
         
         IF  (
               [iitr281] < 0 
               OR 
               [iitr285] < 0 
               OR 
               [iitr279] < 0
             ) 
             AND 
             [iitr479] = NULLORBLANK
            RETURN VALIDATION MESSAGE
         ENDIF

		     [iitr279] = bafpr3.xx.xx:Income.PersonalServicesIncome.Net.Amount
         [iitr281] = bafpr1.xx.xx:Income.PrimaryProductionNet.Amount
		     [iitr285] = bafpr1.xx.xx:Income.NonPrimaryProductionNet.Amount
		     [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
    -->
    <assert id="VR.ATO.IITR.300039" diagnostics="DVR.ATO.IITR.300039"
            test="not(
                          (
                            sum($iitr281) &lt; 0
                            or
                            sum($iitr285) &lt; 0
                            or
                            sum($iitr279) &lt; 0
                          )
                          and
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0])
                      )" />


    <!-- Rule ID: VR.ATO.IITR.300040
         ELS Ref: V1541
         
         IF  (
              [iitr242] < 0 
              OR 
              [iitr252] < 0
             )
             AND 
             [iitr479] = NULLORBLANK
           RETURN VALIDATION MESSAGE
         ENDIF

        [iitr479:1] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 1)

		     [iitr242] = bafpr1.xx.xx:Income.PartnershipPrimaryProductionShare.Amount
		     [iitr252] = bafpr1.xx.xx:Income.PartnershipLessForeignIncomeNonPrimaryProductionShare.Amount
		     [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
    -->
    <assert id="VR.ATO.IITR.300040" diagnostics="DVR.ATO.IITR.300040"
            test="not(
                          (
                            sum($iitr242) &lt; 0
                            or
                            sum($iitr252) &lt; 0
                          )
                          and
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $contextReportItemOrderNumber1/@id])
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.310017
         ELS Ref: V104C
         
         IF (
              [iitr436] <> NULL 
              OR 
              [iitr437] <> NULL 
              OR 
              [iitr438] <> NULL 
              OR
              [iitr439] <> NULL
              OR
              [iitr440] <> NULL
              OR 
              [iitr441] <> NULL 
              OR 
              [iitr442] <> NULL 
              OR
              [iitr443] <> NULL
              OR 
              [iitr445] <> NULL 
              OR 
              [iitr447] <> NULL 
              OR
              [iitr448] <> NULL 
            ) 
            AND 
            [iitr421] = NULL
              RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr421] = bafpr3.xx.xx:Income.PersonalServicesIncome.BusinessActivities.Count
         [iitr436] = bafpr1.xx.xx:Income.ABNNotQuotedPrimaryProductionPaymentGross.Amount
         [iitr437] = bafpr1.xx.xx:Income.ABNNotQuotedNonPrimaryProductionPaymentGross.Amount
         [iitr438] = bafpr1.xx.xx:Income.ForeignResidentWithholdingNonPrimaryProduction.Amount
         [iitr439] = bafpr1.xx.xx:Income.VoluntaryAgreementPrimaryProductionGross.Amount
         [iitr440] = bafpr1.xx.xx:Income.VoluntaryAgreementNonPrimaryProductionGross.Amount
         [iitr441] = bafpr1.xx.xx:Income.LabourHireArrangementPrimaryProductionPaymentGross.Amount
         [iitr442] = bafpr1.xx.xx:Income.LabourHireArrangementNonPrimaryProductionPaymentGross.Amount
         [iitr443] = bafpr1.xx.xx:Income.GovernmentIndustryPrimaryProductionPaymentsAssessable.Amount
         [iitr445] = bafpr1.xx.xx:Income.GovernmentIndustryNonPrimaryProductionPaymentsAssessable.Amount
         [iitr447] = bafpr1.xx.xx:Income.BusinessPrimaryProductionOther.Amount
         [iitr448] = bafpr1.xx.xx:Income.BusinessNonPrimaryProductionOther.Amount
      -->
    <assert id="VR.ATO.IITR.310017" diagnostics="DVR.ATO.IITR.310017"
            test="not(
                          not($iitr421[not(@i:nil='true')])
                          and
                          (
                            $iitr436[not(@i:nil='true')]
                            or
                            $iitr437[not(@i:nil='true')]
                            or
                            $iitr438[not(@i:nil='true')]
                            or
                            $iitr439[not(@i:nil='true')]
                            or
                            $iitr440[not(@i:nil='true')]
                            or
                            $iitr441[not(@i:nil='true')]
                            or
                            $iitr442[not(@i:nil='true')]
                            or
                            $iitr443[not(@i:nil='true')]
                            or
                            $iitr445[not(@i:nil='true')]
                            or
                            $iitr447[not(@i:nil='true')]
                            or
                            $iitr448[not(@i:nil='true')]
                          )
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.310018
         ELS Ref: V109A
         
         
         IF (
              [iitr436] <> NULL 
              OR 
              [iitr437] <> NULL 
              OR 
              [iitr438] <> NULL 
              OR
              [iitr439] <> NULL
              OR
              [iitr440] <> NULL
              OR 
              [iitr441] <> NULL 
              OR 
              [iitr442] <> NULL 
              OR
              [iitr443] <> NULL
              OR 
              [iitr445] <> NULL 
              OR 
              [iitr447] <> NULL 
              OR
              [iitr448] <> NULL 
            ) 
            AND 
            (
              [iitr425] = NULLORBLANK
                OR 
                [iitr428] = NULLORBLANK
              )
              RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr425] = pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text
         [iitr428] = pyde.xx.xx:AddressDetails.Line1.Text
         [iitr429] = pyde.xx.xx:AddressDetails.Line2.Text
         [iitr436] = bafpr1.xx.xx:Income.ABNNotQuotedPrimaryProductionPaymentGross.Amount
         [iitr437] = bafpr1.xx.xx:Income.ABNNotQuotedNonPrimaryProductionPaymentGross.Amount
         [iitr438] = bafpr1.xx.xx:Income.ForeignResidentWithholdingNonPrimaryProduction.Amount
         [iitr439] = bafpr1.xx.xx:Income.VoluntaryAgreementPrimaryProductionGross.Amount
         [iitr440] = bafpr1.xx.xx:Income.VoluntaryAgreementNonPrimaryProductionGross.Amount
         [iitr441] = bafpr1.xx.xx:Income.LabourHireArrangementPrimaryProductionPaymentGross.Amount
         [iitr442] = bafpr1.xx.xx:Income.LabourHireArrangementNonPrimaryProductionPaymentGross.Amount
         [iitr443] = bafpr1.xx.xx:Income.GovernmentIndustryPrimaryProductionPaymentsAssessable.Amount
         [iitr445] = bafpr1.xx.xx:Income.GovernmentIndustryNonPrimaryProductionPaymentsAssessable.Amount
         [iitr447] = bafpr1.xx.xx:Income.BusinessPrimaryProductionOther.Amount
         [iitr448] = bafpr1.xx.xx:Income.BusinessNonPrimaryProductionOther.Amount
      -->
    <assert id="VR.ATO.IITR.310018" diagnostics="DVR.ATO.IITR.310018"
            test="not(
                          (
                            not($iitr425[not(@i:nil='true')])
                            or
                              not($iitr428[not(@i:nil='true') and string-length(.) != 0])
                            )
                          and
                          (
                            $iitr436[not(@i:nil='true')]
                            or
                            $iitr437[not(@i:nil='true')]
                            or
                            $iitr438[not(@i:nil='true')]
                            or
                            $iitr439[not(@i:nil='true')]
                            or
                            $iitr440[not(@i:nil='true')]
                            or
                            $iitr441[not(@i:nil='true')]
                            or
                            $iitr442[not(@i:nil='true')]
                            or
                            $iitr443[not(@i:nil='true')]
                            or
                            $iitr445[not(@i:nil='true')]
                            or
                            $iitr447[not(@i:nil='true')]
                            or
                            $iitr448[not(@i:nil='true')]
                          )
                       )"/>


    <!-- Rule ID: VR.ATO.IITR.400005
         ELS Ref: V2721
         
        IF ([iitr13] <> "Short") 
           AND 
           (
              [iitr200] = NULL OR 
              [iitr201] = NULL OR 
              [iitr202] = NULL OR 
              [iitr203] = NULL OR 
              [iitr204] = NULL OR 
              [iitr205] = NULL OR 
              [iitr206] = NULL
           )
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr13]  = rvctc1.xx.xx:IncomeTax.ReturnType.Code
		    [iitr200] = bafpr1.xx.xx:Income.FringeBenefitsReportable.Amount
		    [iitr201] = emsup.xx.xx:SuperannuationContribution.EmployerReportable.Amount
		    [iitr202] = gfapc.xx.xx:Pension.TaxFree.Amount
		    [iitr203] = rvctc4.xx.xx:InternationalDealings.ForeignIncomeTarget.Amount
		    [iitr204] = rvctc3.xx.xx:Tax.Losses.FinancialInvestmentNet.Amount
		    [iitr205] = rvctc3.xx.xx:Tax.Losses.RentalPropertyNet.Amount
		    [iitr206] = cssup.xx.xx:ChildSupport.Payment.Amount
    -->
    <assert id="VR.ATO.IITR.400005" diagnostics="DVR.ATO.IITR.400005"
            test="not(
                          not($iitr13[. = 'Short'])
                          and
                          (
                              not($iitr200[not(@i:nil='true')])
                              or
                              not($iitr201[not(@i:nil='true')])
                              or
                              not($iitr202[not(@i:nil='true')])
                              or
                              not($iitr203[not(@i:nil='true')])
                              or
                              not($iitr204[not(@i:nil='true')])
                              or
                              not($iitr205[not(@i:nil='true')])
                              or
                              not($iitr206[not(@i:nil='true')])                              
                          )                  
                      )" />


    <!-- Rule ID: VR.ATO.IITR.400007
         ELS Ref: V126

		    IF ([iitr124] <> NULLORBLANK OR [iitr215] <> NULLORBLANK) AND ([iitr213] = NULLORBLANK OR [iitr214]  =NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr124] = bafpr3.xx.xx:Income.EmployeeShareScheme.TaxUpfrontNonReducibleDiscount.Amount
		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
		    [iitr215] = pyde.xx.xx:PersonNameDetails.OtherGivenName.Text
    -->
    <assert id="VR.ATO.IITR.400007" diagnostics="DVR.ATO.IITR.400007"
            test="not(
                          (
                              $iitr214[not(@i:nil='true') and string-length(.) != 0]
                              or
                              $iitr215[not(@i:nil='true') and string-length(.) != 0]
                          )
                          and
                          (
                              not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                              or
                              not($iitr214[not(@i:nil='true') and string-length(.) != 0])
                          )                                        
                      )" />


    <!-- Rule ID: VR.ATO.IITR.400008
         ELS Ref: V137A

		    IF ([iitr213] = FOUND("Exec for","Rep for","Trustee for"))
           RETURN VALIDATION MESSAGE
        ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
    -->
    <assert id="VR.ATO.IITR.400008" diagnostics="DVR.ATO.IITR.400008"
            test="not(
                         $iitr213
                         [
                             matches(.,'^(Exec for |Rep for |Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for | Rep for | Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for| Rep for| Trustee for)$','i') or
                             matches(.,'^(Exec for|Rep for|Trustee for)$','i')
                         ]            
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.400009
         ELS Ref: V137A

		    IF ([iitr214] = FOUND("Exec for","Rep for","Trustee for"))
           RETURN VALIDATION MESSAGE
        ENDIF

		    [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
    -->
    <assert id="VR.ATO.IITR.400009" diagnostics="DVR.ATO.IITR.400009"
            test="not(
                         $iitr214
                         [
                             matches(.,'^(Exec for |Rep for |Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for | Rep for | Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for| Rep for| Trustee for)$','i') or
                             matches(.,'^(Exec for|Rep for|Trustee for)$','i')
                         ]            
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.400010
         ELS Ref: V137A

		    IF ([iitr215] = FOUND("Exec for","Rep for","Trustee for"))
           RETURN VALIDATION MESSAGE
        ENDIF

		    [iitr215] = pyde.xx.xx:PersonNameDetails.OtherGivenName.Text
    -->
    <assert id="VR.ATO.IITR.400010" diagnostics="DVR.ATO.IITR.400010"
            test="not(
                         $iitr215
                         [
                             matches(.,'^(Exec for |Rep for |Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for | Rep for | Trustee for )(.*)$','i') or
                             matches(.,'^(.*)( Exec for| Rep for| Trustee for)$','i') or
                             matches(.,'^(Exec for|Rep for|Trustee for)$','i')
                         ]            
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.400021
         ELS Ref: V140

		    IF ([iitr213] = FOUND("MR","MRS","MISS","MS"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
    -->
    <assert id="VR.ATO.IITR.400021" diagnostics="DVR.ATO.IITR.400021"
            test="not(
                         $iitr213
                         [
                              matches(.,'^(MR |MRS |MISS |MS )(.*)$','i') or
                              matches(.,'^(.*)( MR | MRS | MISS | MS )(.*)$','i') or
                              matches(.,'^(.*)( MR| MRS| MISS| MS)$','i') or
                              matches(.,'^(MR|MRS|MISS|MS)$','i')
                         ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400022
         ELS Ref: V140

		    IF ([iitr214] = FOUND("MR","MRS","MISS","MS"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
    -->
    <assert id="VR.ATO.IITR.400022" diagnostics="DVR.ATO.IITR.400022"
            test="not(
                         $iitr214
                         [
                              matches(.,'^(MR |MRS |MISS |MS )(.*)$','i') or
                              matches(.,'^(.*)( MR | MRS | MISS | MS )(.*)$','i') or
                              matches(.,'^(.*)( MR| MRS| MISS| MS)$','i') or
                              matches(.,'^(MR|MRS|MISS|MS)$','i')
                         ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400023
         ELS Ref: V140

		    IF ([iitr215] = FOUND("MR","MRS","MISS","MS"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr215] = pyde.xx.xx:PersonNameDetails.OtherGivenName.Text
    -->
    <assert id="VR.ATO.IITR.400023" diagnostics="DVR.ATO.IITR.400023"
            test="not(
                         $iitr215
                         [
                              matches(.,'^(MR |MRS |MISS |MS )(.*)$','i') or
                              matches(.,'^(.*)( MR | MRS | MISS | MS )(.*)$','i') or
                              matches(.,'^(.*)( MR| MRS| MISS| MS)$','i') or
                              matches(.,'^(MR|MRS|MISS|MS)$','i')
                         ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400024
         ELS Ref: V141

		    IF ([iitr213] = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
    -->
    <assert id="VR.ATO.IITR.400024" diagnostics="DVR.ATO.IITR.400024"
            test="not(
                          $iitr213
                          [
                              matches(.,'^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$','i') or
                              matches(.,'^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$','i')
                          ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400025
         ELS Ref: V141

		    IF ([iitr214] = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
    -->
    <assert id="VR.ATO.IITR.400025" diagnostics="DVR.ATO.IITR.400025"
            test="not(
                          $iitr214
                          [
                              matches(.,'^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$','i') or
                              matches(.,'^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$','i')
                          ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400026
         ELS Ref: V141

		    IF ([iitr215] = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr215] = pyde.xx.xx:PersonNameDetails.OtherGivenName.Text
    -->
    <assert id="VR.ATO.IITR.400026" diagnostics="DVR.ATO.IITR.400026"
            test="not(
                          $iitr215
                          [
                              matches(.,'^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$','i') or
                              matches(.,'^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$','i') or
                              matches(.,'^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$','i')
                          ]
                     )"/>


    <!-- Rule ID: VR.ATO.IITR.400027
         ELS Ref: V153A

		    IF  ([iitr220] = FALSE) 
            AND 
            ([iitr221] = NULL) 
            AND 
            ([iitr222] = NULL) 
            AND 
            (
                [iitr217] <> NULL OR [iitr225] <> NULL OR [iitr226] <> NULL OR [iitr227] <> NULL OR [iitr228] <> NULL OR 
                [iitr229] <> NULL OR [iitr230] <> NULL OR [iitr213] <> NULLORBLANK OR [iitr231] <> NULL OR 
                [iitr232] <> NULL OR [iitr233] <> NULL OR [iitr234] <> NULL OR [iitr235] <> NULL
            )
		           RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
		    [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
		    [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount
		    [iitr226] = rvctc1.xx.xx:IncomeTax.TrustIncomeNotIncludedInTaxableIncome.Amount
		    [iitr227] = rvctc1.xx.xx:IncomeTax.FamilyTrustDistributionWhereTaxPaid.Amount
		    [iitr228] = bafpr1.xx.xx:Income.FringeBenefitsReportable.Amount
		    [iitr229] = gfapc.xx.xx:Pension.Total.Amount
		    [iitr230] = gfapc.xx.xx:Pension.SpouseExempt.Amount
		    [iitr231] = emsup.xx.xx:SuperannuationContribution.EmployerReportable.Amount
		    [iitr232] = gfapc.xx.xx:Pension.TaxFreeMilitaryRehabilitationCompensation.Amount
		    [iitr233] = rvctc4.xx.xx:InternationalDealings.ForeignIncomeTarget.Amount
		    [iitr234] = rvctc3.xx.xx:Tax.Losses.InvestmentNet.Amount
		    [iitr235] = cssup.xx.xx:ChildSupport.Payment.Amount
    -->
    <assert id="VR.ATO.IITR.400027" diagnostics="DVR.ATO.IITR.400027"
            test="not(
                          (
                              $iitr220[matches(.,'^(false|0)$')]
                              and
                              not($iitr221[not(@i:nil='true')])
                              and
                              not($iitr222[not(@i:nil='true')])
                              and
                              (
                                  $iitr217[not(@i:nil='true')]
                                  or
                                  $iitr225[not(@i:nil='true')]
                                  or
                                  $iitr226[not(@i:nil='true')]
                                  or
                                  $iitr227[not(@i:nil='true')]
                                  or
                                  $iitr228[not(@i:nil='true')]
                                  or
                                  $iitr229[not(@i:nil='true')]
                                  or
                                  $iitr230[not(@i:nil='true')]
                                  or
                                  $iitr213[not(@i:nil='true') and string-length(.) != 0]
                                  or
                                  $iitr231[not(@i:nil='true')]
                                  or
                                  $iitr232[not(@i:nil='true')]
                                  or
                                  $iitr233[not(@i:nil='true')]
                                  or
                                  $iitr234[not(@i:nil='true')]
                                  or
                                  $iitr235[not(@i:nil='true')]                                  
                              )
                          )                             
                     )" />


    <!-- Rule ID: VR.ATO.IITR.400028
         ELS Ref: V281

		    IF ([iitr220] = TRUE OR ([iitr221] <> NULL OR [iitr222]  <> NULL)) AND ([iitr213] = NULLORBLANK AND [iitr225] = NULL)
            RETURN VALIDATION MESSAGE
        ENDIF

		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
		    [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
		    [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount
    -->
    <assert id="VR.ATO.IITR.400028" diagnostics="DVR.ATO.IITR.400028"
            test="not(
                          (
                              $iitr220[matches(.,'^(true|1)$')]
                              or
                              $iitr221[not(@i:nil='true')]
                              or
                              $iitr222[not(@i:nil='true')]
                          )
                          and
                          (
                              not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                              and
                              not($iitr225[not(@i:nil='true')])
                          )
                     )" />


    <!-- Rule ID: VR.ATO.IITR.400030
         ELS Ref: V153W

		    IF ([iitr217] <> NULL OR [iitr221] <> NULL OR [iitr222] <> NULL OR [iitr229] <> NULL OR [iitr237] <> NULL) AND ([iitr220] = NULL)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
		    [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
		    [iitr229] = gfapc.xx.xx:Pension.Total.Amount
		    [iitr237] = bafpr1.xx.xx:Income.TaxableAdjusted.Amount
    -->
    <assert id="VR.ATO.IITR.400030" diagnostics="DVR.ATO.IITR.400030"
            test="not(
                          (
                              $iitr217[not(@i:nil='true')]
                              or
                              $iitr221[not(@i:nil='true')]
                              or
                              $iitr222[not(@i:nil='true')]
                              or
                              $iitr229[not(@i:nil='true')]
                              or
                              $iitr237[not(@i:nil='true')]
                          )   
                          and
                          not($iitr220[not(@i:nil='true')])                          
                     )" />


    <!-- Rule ID: VR.ATO.IITR.400031
         ELS Ref: V312

		    IF ([iitr217] > DATE(TODAY))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
    -->
    <assert id="VR.ATO.IITR.400031" diagnostics="DVR.ATO.IITR.400031"
            test="not(
                          $iitr217
                          [
                              not(@i:nil='true') 
                              and 
                              function:IsDate1GreaterThanDate2(., current-date())
                          ]                              
                     )" />


    <!-- Rule ID: VR.ATO.IITR.400073
         ELS Ref: M505

		     IF ([iitr214] = NULLORBLANK) AND ([iitr213] <> NULLORBLANK)
           RETURN VALIDATION MESSAGE
         ENDIF

		     [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text
         [iitr214] = pyde.xx.xx:PersonNameDetails.GivenName.Text
    -->
    <assert id="VR.ATO.IITR.400073" diagnostics="DVR.ATO.IITR.400073"
            test="not(
                          not($iitr214[not(@i:nil='true') and string-length(.) != 0])
                          and
                          $iitr213[not(@i:nil='true') and string-length(.) != 0]
                     )" />


    <!-- Rule ID: VR.ATO.IITR.400151
         ELS Ref: V193
         
         IF [iitr221] = RP:Period.startDate AND [iitr222] = RP:Period.endDate
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
         [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
      -->
    <assert id="VR.ATO.IITR.400151" diagnostics="DVR.ATO.IITR.400151"
            test="not(
                          $iitr221[. = $startDate]
                          and
                          $iitr222[. = $endDate]
                       )"/>


    <!-- Rule ID: VR.ATO.IITR.410000
         ELS Ref: V1499
         
         IF [iitr419] <> NULLORBLANK AND [iitr421] = NULL
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr419] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr421] = bafpr3.xx.xx:Income.PersonalServicesIncome.BusinessActivities.Count
      -->
    <assert id="VR.ATO.IITR.410000" diagnostics="DVR.ATO.IITR.410000"
            test="not(
                          $iitr419[not(@i:nil='true') and string-length(.) != 0]
                          and
                          not($iitr421[not(@i:nil='true')])
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.410001
         ELS Ref: V210J
         
         IF (
              [iitr428] <> NULLORBLANK 
              OR 
              [iitr429] <> NULLORBLANK 
              OR 
              [iitr430] <> NULLORBLANK 
              OR 
              [iitr431] <> NULL 
              OR 
              [iitr432] <> NULLORBLANK
            )
            AND 
            (
              [iitr428] = NULLORBLANK 
              OR 
              [iitr430] = NULLORBLANK 
              OR 
              [iitr431] = NULLORBLANK 
              OR 
              [iitr432] = NULLORBLANK
            )
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr419] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr421] = bafpr3.xx.xx:Income.PersonalServicesIncome.BusinessActivities.Count
      -->
    <assert id="VR.ATO.IITR.410001" diagnostics="DVR.ATO.IITR.410001"
            test="not(
                          (
                            $iitr428[not(@i:nil='true') and string-length(.) != 0]
                            or
                            $iitr429[not(@i:nil='true') and string-length(.) != 0]
                            or
                            $iitr430[not(@i:nil='true') and string-length(.) != 0]
                            or
                            $iitr431[not(@i:nil='true')]
                            or
                            $iitr432[not(@i:nil='true') and string-length(.) != 0]
                          )
                          and
                          (
                            not($iitr428[not(@i:nil='true') and string-length(.) != 0])
                            or
                            not($iitr430[not(@i:nil='true') and string-length(.) != 0])
                            or
                            not($iitr431[not(@i:nil='true') and string-length(.) != 0])
                            or
                            not($iitr432[not(@i:nil='true') and string-length(.) != 0])
                          )
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.410005
         ELS Ref: V255A
    
         IF [iitr514] > 0 AND [iitr516] = NULLORBLANK
            RETURN VALIDATION MESSAGE
         ENDIF
        
         [iitr514] = lrla.xx.xx:Remuneration.WagesAndSalaries.Total.Amount
         [iitr516] = lrla.xx.xx:Remuneration.WagesAndSalariesAction.Code
    -->
    <assert id="VR.ATO.IITR.410005" diagnostics="DVR.ATO.IITR.410005"
            test="not(
                        sum($iitr514) > 0
                        and
                        not($iitr516[not(@i:nil='true') and string-length(.) != 0])
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410007
         ELS Ref: V255B
    
         IF [iitr516] <> NULLORBLANK AND ([iitr514] = NULL OR [iitr514] = 0)
            RETURN VALIDATION MESSAGE
         ENDIF
        
         [iitr514] = lrla.xx.xx:Remuneration.WagesAndSalaries.Total.Amount
         [iitr516] = lrla.xx.xx:Remuneration.WagesAndSalariesAction.Code
    -->
    <assert id="VR.ATO.IITR.410007" diagnostics="DVR.ATO.IITR.410007"
            test="not(
                        $iitr516[not(@i:nil='true') and string-length(.) != 0]
                        and
                        sum($iitr514) = 0
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410008
    
        IF ([iitr430] = FOUND("QLD","NSW","VIC","SA","WA","NT","ACT","TAS"))
           RETURN VALIDATION MESSAGE
        ENDIF
        
        [iitr430] = pyde.02.00:AddressDetails.LocalityName.Text (Business)
    -->
    <assert id="VR.ATO.IITR.410008" diagnostics="DVR.ATO.IITR.410008"
            test="not(
                        $iitr430[
                                  matches(.,'(\s+|^)(QLD|NSW|VIC|SA|WA|NT|ACT|TAS)(\s+|$)','i')
                                ]
                     )" />


    <!-- Rule ID: VR.ATO.IITR.410009
         ELS Ref: V109B
         
         IF (
              [iitr425] <> NULLORBLANK 
              OR 
              [iitr428] <> NULLORBLANK 
            ) 
            AND 
            (
              [iitr436] = NULL 
              AND 
              [iitr437] = NULL 
              AND 
              [iitr438] = NULL 
              AND 
              [iitr439] = NULL 
              AND 
              [iitr440] = NULL 
              AND 
              [iitr441] = NULL 
              AND 
              [iitr442] = NULL 
              AND 
              [iitr443] = NULL 
              AND 
              [iitr445] = NULL 
              AND 
              [iitr447] = NULL 
              AND 
              [iitr448] = NULL
            )
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr425] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr428] = pyde.02.00:AddressDetails.Line1.Text
         [iitr436] = bafpr1.xx.xx:Income.ABNNotQuotedPrimaryProductionPaymentGross.Amount
         [iitr437] = bafpr1.xx.xx:Income.ABNNotQuotedNonPrimaryProductionPaymentGross.Amount
         [iitr438] = bafpr1.xx.xx:Income.ForeignResidentWithholdingNonPrimaryProduction.Amount
         [iitr439] = bafpr1.xx.xx:Income.VoluntaryAgreementPrimaryProductionGross.Amount
         [iitr440] = bafpr1.xx.xx:Income.VoluntaryAgreementNonPrimaryProductionGross.Amount
         [iitr441] = bafpr1.xx.xx:Income.LabourHireArrangementPrimaryProductionPaymentGross.Amount
         [iitr442] = bafpr1.xx.xx:Income.LabourHireArrangementNonPrimaryProductionPaymentGross.Amount
         [iitr443] = bafpr1.xx.xx:Income.GovernmentIndustryPrimaryProductionPaymentsAssessable.Amount
         [iitr445] = bafpr1.xx.xx:Income.GovernmentIndustryNonPrimaryProductionPaymentsAssessable.Amount
         [iitr447] = bafpr1.xx.xx:Income.BusinessPrimaryProductionOther.Amount
         [iitr448] = bafpr1.xx.xx:Income.BusinessNonPrimaryProductionOther.Amount
      -->
    <assert id="VR.ATO.IITR.410009" diagnostics="DVR.ATO.IITR.410009"
            test="not(
                          (
                            $iitr425[not(@i:nil='true') and string-length(.) != 0]
                            or
                            $iitr428[not(@i:nil='true') and string-length(.) != 0]
                          )
                          and
                          (
                            not($iitr436[not(@i:nil='true')])
                            and
                            not($iitr437[not(@i:nil='true')])
                            and
                            not($iitr438[not(@i:nil='true')])
                            and
                            not($iitr439[not(@i:nil='true')])
                            and
                            not($iitr440[not(@i:nil='true')])
                            and
                            not($iitr441[not(@i:nil='true')])
                            and
                            not($iitr442[not(@i:nil='true')])
                            and
                            not($iitr443[not(@i:nil='true')])
                            and
                            not($iitr445[not(@i:nil='true')])
                            and
                            not($iitr447[not(@i:nil='true')])
                            and
                            not($iitr448[not(@i:nil='true')])
                          )
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.410010
         ELS Ref: V1539
    
         IF ([iitr479:2] <> NULL AND [iitr479:1] = NULL) OR ([iitr479:3] <> NULL AND [iitr479:2] = NULL)
            RETURN VALIDATION MESSAGE
         ENDIF

         [iitr479:1] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 1)
         [iitr479:2] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 2)
         [iitr479:3] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 3)

         [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
    -->
    <assert id="VR.ATO.IITR.410010" diagnostics="DVR.ATO.IITR.410010"
            test="not(
                        (
                          $iitr479[not(@i:nil='true') and @contextRef = $contextReportItemOrderNumber2/@id]
                          and
                          not($iitr479[not(@i:nil='true') and @contextRef = $contextReportItemOrderNumber1/@id])
                        )
                        or
                        (
                          $iitr479[not(@i:nil='true') and @contextRef = $contextReportItemOrderNumber3/@id]
                          and
                          not($iitr479[not(@i:nil='true') and @contextRef = $contextReportItemOrderNumber2/@id])
                        )
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410012
         ELS Ref: V2089A

        IF ([iitr482:1] = 8) AND ([iitr482:2] = 8) AND ([iitr482:3] = 8) AND (SUM([iitr487]) > ([iitr299] + [iitr300]))
            RETURN VALIDATION MESSAGE
         ENDIF
        
         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr482:1] = ([iitr482] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 1)
         [iitr482:2] = ([iitr482] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 2)
         [iitr482:3] = ([iitr482] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 3)
         [iitr487] = rvctc3.xx.xx:Tax.Losses.Net.Amount
         [iitr229] = gfapc.xx.xx:Pension.Total.Amount
         [iitr300] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialNonPrimaryProduction.Amount
    -->
    <let name="ltc8" value="$iitr482[. = 8]/@contextRef" />
    <assert id="VR.ATO.IITR.410012" diagnostics="DVR.ATO.IITR.410012"
            test="not(
                      (
                           $iitr482[.='8' and @contextRef = $contextReportItemOrderNumber1/@id]
                          and
                          $iitr482[.='8' and @contextRef = $contextReportItemOrderNumber2/@id]
                          and
                          $iitr482[.='8' and @contextRef = $contextReportItemOrderNumber3/@id]
                       )
                       and                          
                        sum($iitr487) > sum($iitr299|$iitr300)
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410018
         ELS Ref: V35
         
         IF (([iitr299] + [iitr300]) > 0) AND (ALL OCCURRENCES OF ([iitr479]) = NULLORBLANK)
           RETURN VALIDATION MESSAGE
         ENDIF

         [iitr299] = pyde.xx.xx:PersonDemographicDetails.Sex.Code
         [iitr300] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialNonPrimaryProduction.Amount
         [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
      -->
    <assert id="VR.ATO.IITR.410018" diagnostics="DVR.ATO.IITR.410018"
            test="not(
                          sum($iitr299|$iitr300) > 0
                          and
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0])
                       )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.410026
         ELS Ref: V35
         
         IF ([iitr218] <> NULLORBLANK) AND ([iitr218] <> SET("1","2","3"))
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr218] = pyde.xx.xx:PersonDemographicDetails.Sex.Code    
      -->
    <assert id="VR.ATO.IITR.410026" diagnostics="DVR.ATO.IITR.410026"
            test="not(
                          $iitr218[not(@i:nil='true')]
                          and
                          $iitr218[not(. = '1' or . = '2' or . = '3')]
                       )"/>


    <!-- Rule ID: VR.ATO.IITR.410034
         ELS Ref: V2357
         
         IF ([iitr223] <> TRUE) AND ((([iitr237] = NULL) AND ((([iitr225] + (ConditionalValue([iitr228] > 3920,[iitr228],0) * 0.510) + [iitr233] + [iitr230] + [iitr232] + [iitr234] + [iitr231] - [iitr235]) +/- 1) <> 0)) OR (([iitr237] <> NULL) AND ([iitr237] <> ([iitr225] + (ConditionalValue([iitr228] > 3920, [iitr228],0) * 0.510) + [iitr233] + [iitr230] + [iitr232] + [iitr234] + [iitr231] - [iitr235]) +/- 1)))
              RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr223] = pyde.xx.xx:PersonDemographicDetails.Deceased.Indicator
         [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount
         [iitr228] = bafpr1.xx.xx:Income.FringeBenefitsReportable.Amount
         [iitr230] = gfapc.xx.xx:Pension.SpouseExempt.Amount
         [iitr231] = emsup.xx.xx:SuperannuationContribution.EmployerReportable.Amount
         [iitr232] = gfapc.xx.xx:Pension.TaxFreeMilitaryRehabilitationCompensation.Amount
         [iitr233] = rvctc4.xx.xx:InternationalDealings.ForeignIncomeTarget.Amount
         [iitr234] = rvctc3.xx.xx:Tax.Losses.InvestmentNet.Amount
         [iitr235] = cssup.xx.xx:ChildSupport.Payment.Amount
         [iitr237] = bafpr1.xx.xx:Income.TaxableAdjusted.Amount
      -->
    <let name="totalSum" value="sum($iitr225 | $iitr233 | $iitr230 | $iitr232 | $iitr234 | $iitr231) 
                                   + 
                                   (sum($iitr228[. > 3920]) * 0.510) 
                                   - 
                                   sum($iitr235)" />
    
    <assert  id="VR.ATO.IITR.410034" diagnostics="DVR.ATO.IITR.410034"
            test="not(
                          not($iitr223[matches(.,'^(true|1)$')])
                          and 
                          (
                            (
	                                not($iitr237[not(@i:nil='true')])
	                                and 
                              (
	                                    0 &lt; $totalSum - 1
                                or
                                      0 > $totalSum + 1
                              )
                            ) 
                            or 
                            (
	                                $iitr237[not(@i:nil='true')]
                              and 
                              (
	                                    sum($iitr237) &lt; $totalSum - 1
                                    or
                                      sum($iitr237) > $totalSum + 1
                              )
                            )
                          )
                       )"/>

    
    <!-- Rule ID: VR.ATO.IITR.410152
         ELS Ref: V1200
      
         IF ([iitr426] <> NULLORBLANK) AND (ABNALGORITHM([iitr426]) = FALSE)
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr426] = pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier
    -->
    <assert id="VR.ATO.IITR.410152" diagnostics="DVR.ATO.IITR.410152"
            test="not(
                        $iitr426
                        [
                            not(@i:nil='true') 
                            and 
                            string-length(.) != 0 
                            and 
                            not(function:ValidateABN(.))
                        ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.410189
         ELS Ref: V270
    
         IF ([iitr221] <> NULL OR [iitr222] <> NULL) AND ([iitr221] = NULL OR [iitr222] = NULL)
            RETURN VALIDATION MESSAGE
         ENDIF
        
         [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date
		     [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date
    -->
    <assert id="VR.ATO.IITR.410189" diagnostics="DVR.ATO.IITR.410189"
            test="not(
                        (
                            $iitr221[not(@i:nil='true')]
                            or
                            $iitr222[not(@i:nil='true')]
                        )
                        and
                        (
                            not($iitr221[not(@i:nil='true')])
                            or
                            not($iitr222[not(@i:nil='true')])
                        )              
                     )" />    

    
    <!-- Rule ID: VR.ATO.IITR.410190
         ELS Ref: V1495
    
        WHERE IN CONTEXT(RP.{LOSSSeqNum})
        IF ([iitr299] + [iitr300]) > 0 AND ConditionalValue(RP.{LOSSSeqNum}:LossesSequenceContainer = 1, [iitr480], NULL) = NULL
           RETURN VALIDATION MESSAGE
        ENDIF
        
         [iitr299] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialPrimaryProduction.Amount
         [iitr300] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialNonPrimaryProduction.Amount
         [iitr480] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
    -->
    <assert id="VR.ATO.IITR.410190" diagnostics="DVR.ATO.IITR.410190"
                test="not(
                        not($iitr480[not(@i:nil='true') and @contextRef = $contextReportItemOrderNumber1/@id])
                        and
                        sum($iitr299|$iitr300) > 0
                     )" />
    
    <!-- Rule ID: VR.ATO.IITR.410193
         ELS Ref: V2802
      
         IF (ANY OCCURRENCE OF ([iitr185] = "Claiming your spouses share of rebate")) 
             AND 
             (
                [iitr220] <> TRUE 
                AND 
                [iitr222] <> RP:period.endDate 
                AND 
                [iitr223] <> TRUE
             )
            RETURN VALIDATION MESSAGE
         ENDIF
         
        [iitr185] = rvctc2.02.14:IncomeTax.HealthInsurance.TaxClaim.Code
        [iitr220] = pyde.02.22:PersonDemographicDetails.SpouseFullYear.Indicator
        [iitr222] = pyde.02.22:PersonDemographicDetails.SpouseRelationshipEnd.Date
        [iitr223] = pyde.02.00:PersonDemographicDetails.Deceased.Indicator
    -->
    <assert id="VR.ATO.IITR.410193" diagnostics="DVR.ATO.IITR.410193"
            test="not(
                        $iitr185[. = 'Claiming your spouses share of rebate']
                        and
                        $iitr220[not(matches(.,'^(true|1)$'))]
                        and
                        $iitr222[. != $endDate]
                        and
                        $iitr223[not(matches(.,'^(true|1)$'))]
                     )"/>      
  </rule>

  <!-- LOOP THROUGH REPORTING PARTY PRIVATE HEALTH INSURANCE SEQUENCE CONTEXTS -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $IITR.RPPHISEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.IITR.210015
         ELS Ref: V2687

        IF (ANY OCCURRENCE OF ([iitr185]) = SET("Covered as dependent child", "No dependants") AND ([iitr207] > 0))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
		    [iitr207] = pyde.xx.xx:PersonDemographicDetails.DependentChildren.Count
    -->
    <assert id="VR.ATO.IITR.210015" diagnostics="DVR.ATO.IITR.210015"
            test="not(
                          $iitr185
                          [
                              (. = 'Covered as dependent child' or . = 'No dependants')
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          sum($iitr207) > 0
                      )" />


    <!-- Rule ID: VR.ATO.IITR.210016
         ELS Ref: V2691
                 
        IF  (ANY OCCURRENCE OF ([iitr185]) = SET("Claiming your share of rebate", "Claiming your spouses share of rebate")) 
            AND 
            (
                (
                    [iitr213] = NULLORBLANK 
                    OR 
                    [iitr217] = NULL 
                    OR 
                    (
                        [iitr220] = TRUE 
                        AND 
                        (
                            [iitr221] <> NULL 
                            OR 
                            [iitr222] <> NULL
                        )
                    )
                ) 
                OR 
                (
                    [iitr220] <> TRUE 
                    AND 
                    ( 
                        [iitr221] = NULL 
                        OR 
                        [iitr222] = NULL
                     )
                ) 
                OR 
                (
                    [iitr225] = NULL 
                    OR 
                    [iitr207] = NULL
                )
            )                         
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code              RP.{PHISeqNum}
		    [iitr207] = pyde.xx.xx:PersonDemographicDetails.DependentChildren.Count       RP
		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text                      RP.SPOUSE
		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date                    RP.SPOUSE
		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator      RP
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date  RP
		    [iitr222] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipEnd.Date    RP
		    [iitr225] = bafpr1.xx.xx:Income.Taxable.Amount                                RP.SPOUSE
    -->
    <assert id="VR.ATO.IITR.210016" diagnostics="DVR.ATO.IITR.210016"
            test="not(
                          $iitr185
                          [
                              (. = 'Claiming your share of rebate' or . = 'Claiming your spouses share of rebate')
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          (
                              (
                                  not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                                  or
                                  not($iitr217[not(@i:nil='true')])
                                  or
                                  (
                                      $iitr220[matches(.,'^(true|1)$')]
			                                and
			                                (
				                                  $iitr221[not(@i:nil='true')]
				                                  or
                                          $iitr222[not(@i:nil='true')]				                
			                                )
		                              )
                              )
                              or 
	                            (
		                              not($iitr220[matches(.,'^(true|1)$')])
		                              and 
		                              (
			                                not($iitr221[not(@i:nil='true')])
				                              or
                                      not($iitr222[not(@i:nil='true')])
		                              )
	                            ) 
	                            or
	                            (
                                  not($iitr225[not(@i:nil='true')])
				                          or
                                  not($iitr207[not(@i:nil='true')])
	                            )
                          )
                      )" />


    <!-- Rule ID: VR.ATO.IITR.210017
         ELS Ref: V2693

		    IF ANY OCCURRENCE OF ([iitr185] = "Spouse claiming your share of rebate") 
           AND 
           (
              [iitr213] = NULLORBLANK 
              OR 
              [iitr217] = NULL 
              OR 
              (
                  [iitr220] = TRUE 
                  AND 
                  (
                      [iitr221] <> NULL 
                      OR 
                      [iitr222] <> NULL
                  )
              ) 
              OR 
              (
                  [iitr220] <> TRUE 
                  AND 
                  (
                      [iitr221] = NULL 
                      OR 
                      [iitr222] = NULL
                  )
               )
            )
		      RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code              RP.PHI{Seq}
		    [iitr213] = pyde.xx.xx:PersonNameDetails.FamilyName.Text                      RP.SPOUSE
		    [iitr217] = pyde.xx.xx:PersonDemographicDetails.Birth.Date                    RP.SPOUSE
		    [iitr220] = pyde.xx.xx:PersonDemographicDetails.SpouseFullYear.Indicator      RP
		    [iitr221] = pyde.xx.xx:PersonDemographicDetails.SpouseRelationshipStart.Date  RP
    -->
    <assert id="VR.ATO.IITR.210017" diagnostics="DVR.ATO.IITR.210017"
            test="not(
                          $iitr185
                          [
                              . = 'Spouse claiming your share of rebate'
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          (
                              (
                                  not($iitr213[not(@i:nil='true') and string-length(.) != 0])
                                  or
                                  not($iitr217[not(@i:nil='true')])
                                  or
                                  (
                                      $iitr220[matches(.,'^(true|1)$')]
			                                and
			                                (
				                                  $iitr221[not(@i:nil='true')]
				                                  or
                                          $iitr222[not(@i:nil='true')]				                
			                                )
		                              )
                              )
                              or 
	                            (
		                              not($iitr220[matches(.,'^(true|1)$')])
		                              and 
		                              (
			                                not($iitr221[not(@i:nil='true')])
				                              or
                                      not($iitr222[not(@i:nil='true')])
		                              )
	                            ) 	                            
                          )
                      )" />

  </rule>
  
  <!-- LOOP THROUGH REPORTING PARTY LOSS SEQUENCE CONTEXTS -->
  <let name="contextReportItemOrderNumber1" value="/xbrli:xbrl/xbrli:context[@id = $IITR.RPLOSSSEQ.ContextId and xbrli:entity/xbrli:segment/xbrldi:typedMember/LossSqNumDim.02.00:LossesSequenceContainer[. = '1']]" />
  <let name="contextReportItemOrderNumber2" value="/xbrli:xbrl/xbrli:context[@id = $IITR.RPLOSSSEQ.ContextId and xbrli:entity/xbrli:segment/xbrldi:typedMember/LossSqNumDim.02.00:LossesSequenceContainer[. = '2']]" />
  <let name="contextReportItemOrderNumber3" value="/xbrli:xbrl/xbrli:context[@id = $IITR.RPLOSSSEQ.ContextId and xbrli:entity/xbrli:segment/xbrldi:typedMember/LossSqNumDim.02.00:LossesSequenceContainer[. = '3']]" />
  
  <rule context="xbrli:xbrl/xbrli:context[@id = $IITR.RPLOSSSEQ.ContextId]">

    <let name="thisContextId" value="@id" />
    <let name="thisReportItemOrderNumber" value="xbrli:entity/xbrli:segment/xbrldi:typedMember/LossSqNumDim.02.00:LossesSequenceContainer" />
    
    <!-- Rule ID: VR.ATO.IITR.310025
         ELS Ref: V1376
		IF (
				[iitr479:2] = NULLORBLANK  
			AND 
				[iitr479:3] = NULLORBLANK 
			AND 
				[iitr482:1] = 8 
			AND 
				(
					(
						([iitr487:1] = NULL) 
					AND 
						(([iitr299] + [iitr300]) <> 0)
					) 
					OR 
					(
						([iitr487:1] <> NULL) 
						AND 
						([iitr487:1] <> ([iitr299] + [iitr300]))
					)
				)
			)

            RETURN VALIDATION MESSAGE
         ENDIF

         [iitr479:2] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 2)
         [iitr479:3] = ([iitr479] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 3)
         [iitr482:1] = ([iitr482] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 1)
         [iitr487:1] = ([iitr487] WHERE RP.{LOSSSeqNum}:LossesSequenceContainer = 1)

         [iitr299] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialPrimaryProduction.Amount
         [iitr300] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialNonPrimaryProduction.Amount
		     [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
		     [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr487] = rvctc3.xx.xx:Tax.Losses.Net.Amount
    -->
    <assert id="VR.ATO.IITR.310025" diagnostics="DVR.ATO.IITR.310025"
            test="not(
                          
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $contextReportItemOrderNumber2/@id])
                          and
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $contextReportItemOrderNumber3/@id])
                          and
                          $thisReportItemOrderNumber = 1
                          and
                          $iitr482
                          [
                              . = 8
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          sum($iitr487[@contextRef = $thisContextId]) != sum($iitr299|$iitr300)
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.310026
         ELS Ref: V1376

		     IF ANY OCCURRENCE OF([iitr482]) = 8 AND ([iitr299] + [iitr300]) = 0
            RETURN VALIDATION MESSAGE
         ENDIF

         [iitr299] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialPrimaryProduction.Amount
         [iitr300] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialNonPrimaryProduction.Amount
		     [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
		     [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr487] = rvctc3.xx.xx:Tax.Losses.Net.Amount
    -->
    <assert id="VR.ATO.IITR.310026" diagnostics="DVR.ATO.IITR.310026"
            test="not(
                          $iitr482
                          [
                              . = 8
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          sum($iitr299|$iitr300) = 0
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.300037
         ELS Ref: V1376

		     WHERE IN CONTEXT(RP.{LOSSSeqNum})
         IF ([iitr481] = "161" AND [iitr482] = 8) AND [iitr294] = NULL 
            RETURN VALIDATION MESSAGE
         ENDIF

		     [iitr294] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialPartnershipShare.Amount
		     [iitr481] = pyde.xx.xx:OrganisationDetails.OrganisationType.Code
         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
    -->
    <assert id="VR.ATO.IITR.300037" diagnostics="DVR.ATO.IITR.300037"
            test="not(
                          $iitr481
                          [
                              . = 161
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          $iitr482
                          [
                              . = 8
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          not($iitr294[not(@i:nil='true')])
                      )" />
    
  
  <!-- Rule ID: VR.ATO.IITR.310023
         ELS Ref: V1377

         WHERE IN CONTEXT(RP.{LOSSSeqNum})
         IF ([iitr481] = "006" AND [iitr482] = 8) AND [iitr298] = NULL 
            RETURN VALIDATION MESSAGE
         ENDIF

		     [iitr298] = rvctc3.xx.xx:Tax.Losses.DeferredNonCommercialSoleTrader.Amount
		     [iitr481] = pyde.xx.xx:OrganisationDetails.OrganisationType.Code
         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
    -->
    <assert id="VR.ATO.IITR.310023" diagnostics="DVR.ATO.IITR.310023"
            test="not(
                          $iitr481
                          [
                              . = 006
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          $iitr482
                          [
                              . = 8
                              and 
                              @contextRef = $thisContextId
                          ]
                          and
                          not($iitr298[not(@i:nil='true')])
                      )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410006
         ELS Ref: V1379A
        WHERE IN CONTEXT(RP.{LOSSSeqNum})
        IF ([iitr479] <> NULLORBLANK OR [iitr480] <> NULL OR [iitr481] <> NULL OR [iitr482] <> NULL OR [iitr487] <> NULL) 
        AND ([iitr479] = NULLORBLANK OR [iitr480] = NULL OR [iitr481] = NULL OR [iitr482] = NULL OR [iitr487] = NULL)
          RETURN VALIDATION MESSAGE
        ENDIF

         [iitr479] = pyde.xx.xx:OrganisationDetails.MainIncomeActivity.Description
         [iitr480] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
         [iitr481] = pyde.xx.xx:OrganisationDetails.OrganisationType.Code
         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr487] = rvctc3.xx.xx:Tax.Losses.Net.Amount
    -->
    <assert id="VR.ATO.IITR.410006" diagnostics="DVR.ATO.IITR.410006"
            test="not(
                        (
                          $iitr479[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                          or
                          $iitr480[not(@i:nil='true') and @contextRef = $thisContextId]
                          or
                          $iitr481[not(@i:nil='true') and @contextRef = $thisContextId]
                          or
                          $iitr482[not(@i:nil='true') and @contextRef = $thisContextId]
                          or
                          $iitr487[not(@i:nil='true') and @contextRef = $thisContextId]
                        )
                        and
                        (
                          not($iitr479[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                          or
                          not($iitr480[not(@i:nil='true') and @contextRef = $thisContextId])
                          or
                          not($iitr481[not(@i:nil='true') and @contextRef = $thisContextId])
                          or
                          not($iitr482[not(@i:nil='true') and @contextRef = $thisContextId])
                          or
                          not($iitr487[not(@i:nil='true') and @contextRef = $thisContextId])
                        )
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410011
         ELS Ref: V1983A
    
         WHERE IN CONTEXT(RP.{LOSSSeqNum})
         IF ([iitr482] = 5 AND ([iitr489] = NULL AND [iitr485] = NULL))
           RETURN VALIDATION MESSAGE
         ENDIF

         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr485] = rvctc3.xx.xx:Tax.PrivateRulingNumber.Identifier
         [iitr489] = rvctc3.xx.xx:Tax.ProductRulingNumber.Identifier
    -->
    <assert id="VR.ATO.IITR.410011" diagnostics="DVR.ATO.IITR.410011"
            test="not(
                        $iitr482[. = 5 and @contextRef = $thisContextId]
                        and
                        not($iitr489[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                        and
                        not($iitr485[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )" />
    
    
    <!-- Rule ID: VR.ATO.IITR.410014
         ELS Ref: V1983B
    
         WHERE IN CONTEXT(RP.{LOSSSeqNum})
         IF (([iitr482] <> 5) AND ([iitr489] <> NULL OR [iitr485] <> NULL))
            RETURN VALIDATION MESSAGE
         ENDIF

         [iitr482] = rvctc1.xx.xx:IncomeTax.LossesType.Code
         [iitr485] = rvctc3.xx.xx:Tax.PrivateRulingNumber.Identifier
         [iitr489] = rvctc3.xx.xx:Tax.ProductRulingNumber.Identifier
    -->
    <assert id="VR.ATO.IITR.410014" diagnostics="DVR.ATO.IITR.410014"
            test="not(
                        $iitr482[. != 5 and @contextRef = $thisContextId]
                        and
                        (
                        $iitr489[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                          or
                        $iitr485[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId]
                        )
                     )" />
    

    <!-- Rule ID: VR.ATO.IITR.410016
         ELS Ref: V1983C

         WHERE IN CONTEXT(RP.{LOSSSeqNum})
         IF ([iitr488] <> NULL AND [iitr489] = NULL) OR ([iitr489] <> NULL AND [iitr488] = NULL)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [iitr488] = rvctc3.xx.xx:Tax.ProductRuling.Year
		    [iitr489] = rvctc3.xx.xx:Tax.ProductRulingNumber.Identifier
    -->
    <assert id="VR.ATO.IITR.410016" diagnostics="DVR.ATO.IITR.410016"
            test="not(
                        (
                            $iitr488[not(@i:nil='true') and @contextRef = $thisContextId]
                            and
                            not($iitr489[not(@i:nil='true') and @contextRef = $thisContextId])
                        )
                        or
                        (
                            $iitr489[not(@i:nil='true') and @contextRef = $thisContextId]
                            and
                            not($iitr488[not(@i:nil='true') and @contextRef = $thisContextId])
                        )
                      )" />


    <!-- Rule ID: VR.ATO.IITR.410071
         ELS Ref: V35

        IF ([iitr488] <> NULL) AND ([iitr488] <> SET(1998-2016))
          RETURN VALIDATION MESSAGE
        ENDIF
		    [iitr488] = rvctc3.xx.xx:Tax.ProductRuling.Year
    -->
    <assert id="VR.ATO.IITR.410071" diagnostics="DVR.ATO.IITR.410071"
            test="not(
                          $iitr488
                          [
                              not(@i:nil='true') 
                              and @contextRef = $thisContextId
                              and not(. >= 1998 and . &lt;= 2016)
                          ]
                      )" />
            
    
    <!-- Rule ID: VR.ATO.IITR.410068
         ELS Ref: V35
      
      VR.ATO.IITR.410068:
      IF ([iitr481] <> NULL) AND ([iitr481] <> SET("006", "161"))
        RETURN VALIDATION MESSAGE
      ENDIF
         
         [iitr481] = pyde.xx.xx:OrganisationDetails.OrganisationType.Code
    -->
    <assert id="VR.ATO.IITR.410068" diagnostics="DVR.ATO.IITR.410068"
         test="not(
                        $iitr481[
                            not(@i:nil='true')
                            and
                            not(. = 006 or . = 161)
                            and
                            @contextRef = $thisContextId]
                     )"/>



    <!-- Rule ID: VR.ATO.IITR.410151
         ELS Ref: V103
      
         IF ([iitr480] = 97000)
            RETURN VALIDATION MESSAGE
         ENDIF
         
         [iitr480] = pyde.xx.xx:OrganisationDetails.OrganisationIndustry2006Extended.Code
    -->
    <assert id="VR.ATO.IITR.410151" diagnostics="DVR.ATO.IITR.410151"
            test="not(
                        $iitr480[. = 97000 and @contextRef = $thisContextId]
                     )"/>

    <!-- Rule ID: VR.ATO.IITR.700001
          IF ([IITR482]<>0 AND [IITR480] = SET("99991", "99992", "99770", "99780"))
             RETURN VALIDATION MESSAGE
           ENDIF

          [iitr482] = IITR:RP.{LOSSSeqNum}:rvctc1.02.16:IncomeTax.LossesType.Code
          [iitr480] = IITR:RP.{LOSSSeqNum}:pyde.02.14:OrganisationDetails.OrganisationIndustry2006Extended.Code
    -->
    <assert id="VR.ATO.IITR.700001" diagnostics="DVR.ATO.IITR.700001"
            test="not(
                        $iitr482[. != 0 and @contextRef = $thisContextId]
                        and
                        $iitr480[(. = 99991 or . = 99992 or . = 99770 or . = 99780) and @contextRef = $thisContextId]
                     )" />
  </rule>

</pattern>
